Release 0.6.0
=============

The 0.6 series is intended to contain the exact same enhancements and bug fixes
as the 0.5 series. The major difference is the removal of the bundled jQuery
which interferes with the upgraded version shipped with CubicWeb 3.18.
